

#nvpl_lapack-config.cmake
#
# Package COMPONENT's defined:
# Interger types:
#  * lp64 - 32-bit Integer interface
#  * ilp64 - 64-bit Integer interface
# Threading types:
#  * seq - Sequential interface
#  * omp - OpenMP threading interface
#
# Imported interface targets provided:
#  * nvpl::lapack_<lp>_<thr> - shared library targets
#
# Output variables set:
#  * nvpl_lapack_INT_TYPES - List of available integer types for <lp> in targets
#  * nvpl_lapack_THREADING_TYPES - List of available threading types for <thr> in targets
#  * nvpl_lapack_VERSION - Version of installed package
#  * nvpl_lapack_LOCATION - Location this library was found at in local system
#  * nvpl_lapack_BUILD_TYPES - Available CMake BUILD_TYPES found for targets at this location
#  * nvpl_lapack_Fortran_COMPILER_ID - Fortran Compiler ID


set(nvpl_lapack_VERSION 0.2.0)
# build: 386

set(nvpl_lapack_INT_TYPES "lp64;ilp64")
set(nvpl_lapack_THREADING_TYPES "seq;omp")
set(nvpl_lapack_IFACE_OMP_VENDOR "GNU")
set(nvpl_lapack_IFACE_OMP_VENDOR_PREFIX "g")

## Dependencies
include(CMakeFindDependencyMacro)
if(NOT nvpl_blas_FOUND)
    find_dependency(nvpl_blas REQUIRED)
endif()

## Targets
include("${CMAKE_CURRENT_LIST_DIR}/nvpl_lapack-targets.cmake")

# Find component libraries
foreach(_lp IN LISTS nvpl_lapack_INT_TYPES)
    foreach(_thr IN LISTS nvpl_lapack_THREADING_TYPES)
        if(_thr STREQUAL "omp")
            set(_prefix_thr ${nvpl_lapack_IFACE_OMP_VENDOR_PREFIX}${_thr})
        else()
            set(_prefix_thr ${_thr})
        endif()
        set(_tgt nvpl_lapack_${_lp}_${_prefix_thr})

        # Mark COMPONENTs found
        set(nvpl_lapack_${_lp}_FOUND 1)
        set(nvpl_lapack_${_thr}_FOUND 1)

        #Allow Alias to targets
        set_target_properties(${_tgt} PROPERTIES IMPORTED_GLOBAL 1)
        if(TARGET ${_tgt}_static)
            set_target_properties(${_tgt}_static PROPERTIES IMPORTED_GLOBAL 1)
        endif()

        # Add namespaced target aliases if not already created
        if(NOT TARGET nvpl::lapack_${_lp}_${_thr})
            add_library(nvpl::lapack_${_lp}_${_thr} ALIAS ${_tgt})
            if(TARGET ${_tgt}_static)
                add_library(nvpl::lapack_${_lp}_${_thr}_static ALIAS ${_tgt}_static)
            endif()
        endif()
        if(NOT nvpl_lapack_LOCATION)
            get_target_property(nvpl_lapack_LOCATION ${_tgt} LOCATION)
            get_filename_component(nvpl_lapack_LOCATION ${nvpl_lapack_LOCATION} DIRECTORY)
            get_filename_component(nvpl_lapack_LOCATION ${nvpl_lapack_LOCATION}/.. REALPATH)
        endif()
    endforeach()
endforeach()

# Cleanup temporary variables and check if components satisfied
unset(_lp)
unset(_prefix_thr)
unset(_thr)
unset(_tgt)
unset(_lang)
check_required_components(nvpl_lapack)

## Report status
set(_components ${nvpl_lapack_INT_TYPES} ${nvpl_lapack_THREADING_TYPES})
message(STATUS "Found nvpl_lapack: (Location:${nvpl_lapack_LOCATION} Version:${nvpl_lapack_VERSION} ComponentsFound:[${_components}])")
unset(_components)
